@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 import sys
 import argparse
+import logging
 
 # Import libs
 
@@ -15,8 +16,9 @@ import argparse
 #### SERVER ####
 def server(args):
     from lib.server.captcha22 import Captcha22
+    logger = logging.getLogger("Captcha22 Engine")
     server = Captcha22(args.max_steps, args.loss_threshold, args.perplexity_threshold, args.split_percentage,
-                       args.starting_port, args.input_folder, args.work_folder, args.model_folder)
+                       args.starting_port, args.input_folder, args.work_folder, args.model_folder, logger)
     server.main()
 
 #### API ####
@@ -24,8 +26,9 @@ def server(args):
 
 def server_api(args):
     from lib.api.server import ApiServer
+    logger = logging.getLogger("Captcha22 Server API")
     server = ApiServer(args.host, args.port, args.enable_debugging, args.file_drop, args.max_tokens, args.server_location,
-                       args.user_file, args.work_folder, args.model_folder)
+                       args.user_file, args.work_folder, args.model_folder, logger)
     server.main()
 
 
